==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/TableMapper/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TableMapper Module Reference", "index.html", [
    [ "TableMapper Module", "index.html", [
      [ "TableMapper Module Introduction", "index.html#tablemapperintro", null ],
      [ "Inserting Sequence Values with the InboundTableMapper Class", "index.html#inboundtablemapper_sequences", null ],
      [ "TableMapper Examples", "index.html#tablemapperexamples", null ],
      [ "InboundTableMapper Bulk Insert API", "index.html#tablemapper_bulk_insert_api", [
        [ "InboundTableMapper Bulk Insert API Introduction", "index.html#tablemapper_bulk_insert_api_intro", null ],
        [ "InboundTableMapper Bulk Insert API Usage", "index.html#tablemapper_bulk_insert_api_usage", null ],
        [ "InboundTableMapper Bulk Insert API Examples", "index.html#tablemapper_bulk_insert_api_examples", null ]
      ] ],
      [ "TableMapper Specification Format", "index.html#tablemapperkeys", null ],
      [ "Release Notes", "index.html#tablemapperrelnotes", [
        [ "TableMapper v1.3", "index.html#tablemapperv1_3", null ],
        [ "TableMapper v1.2.2", "index.html#tablemapperv1_2_2", null ],
        [ "TableMapper v1.2.1", "index.html#tablemapperv1_2_1", null ],
        [ "TableMapper v1.2", "index.html#tablemapperv1_2", null ],
        [ "TableMapper v1.1.4", "index.html#tablemapperv1_1_4", null ],
        [ "TableMapper v1.1.3", "index.html#tablemapperv1_1_3", null ],
        [ "TableMapper v1.1.2", "index.html#tablemapperv1_1_2", null ],
        [ "TableMapper v1.1.1", "index.html#tablemapperv1_1_1", null ],
        [ "TableMapper v1.1", "index.html#tablemapperv1_1", null ],
        [ "TableMapper v1.0", "index.html#tablemapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.1.tar.bz2: qore-0.9.4.1/docs/modules/TableMapper/html/navtreedata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TableMapper Module Reference", "index.html", [
    [ "TableMapper Module", "index.html", [
      [ "TableMapper Module Introduction", "index.html#tablemapperintro", null ],
      [ "Inserting Sequence Values with the InboundTableMapper Class", "index.html#inboundtablemapper_sequences", null ],
      [ "TableMapper Examples", "index.html#tablemapperexamples", null ],
      [ "InboundTableMapper Bulk Insert API", "index.html#tablemapper_bulk_insert_api", [
        [ "InboundTableMapper Bulk Insert API Introduction", "index.html#tablemapper_bulk_insert_api_intro", null ],
        [ "InboundTableMapper Bulk Insert API Usage", "index.html#tablemapper_bulk_insert_api_usage", null ],
        [ "InboundTableMapper Bulk Insert API Examples", "index.html#tablemapper_bulk_insert_api_examples", null ]
      ] ],
      [ "TableMapper Specification Format", "index.html#tablemapperkeys", null ],
      [ "Release Notes", "index.html#tablemapperrelnotes", [
        [ "TableMapper v1.3", "index.html#tablemapperv1_3", null ],
        [ "TableMapper v1.2.2", "index.html#tablemapperv1_2_2", null ],
        [ "TableMapper v1.2.1", "index.html#tablemapperv1_2_1", null ],
        [ "TableMapper v1.2", "index.html#tablemapperv1_2", null ],
        [ "TableMapper v1.1.4", "index.html#tablemapperv1_1_4", null ],
        [ "TableMapper v1.1.3", "index.html#tablemapperv1_1_3", null ],
        [ "TableMapper v1.1.2", "index.html#tablemapperv1_1_2", null ],
        [ "TableMapper v1.1.1", "index.html#tablemapperv1_1_1", null ],
        [ "TableMapper v1.1", "index.html#tablemapperv1_1", null ],
        [ "TableMapper v1.0", "index.html#tablemapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
